import React, { useMemo } from 'react';
import { tv } from 'tailwind-variants';
import { tabbable } from '../../../libs/tabbable';
import { Button } from '../../Button';
import { Dropdown, DropdownContent, DropdownScrollArea, DropdownTrigger } from '../../Dropdown';
import { FaCaretDownIcon, FaCheckIcon, FaGlobeIcon } from '../../Icon';
const TRIGGER_LABEL = 'Language';
const CHECK_ICON_ALT = '選択中';
const appLauncher = tv({
    slots: {
        switchButton: [
            'shr-border-transparent shr-font-normal shr-text-white shr-transition-transform shr-duration-100 [&]:shr-bg-transparent [&]:shr-px-0.25',
            'hover:shr-border-transparent hover:[&]:shr-bg-transparent',
            'focus-visible:shr-border-transparent focus-visible:[&]:shr-bg-transparent',
            '[&>svg]:aria-[expanded=true]:shr-rotate-180',
        ],
        languageItemsList: ['shr-p-0.5'],
        languageItem: ['shr-flex shr-items-center'],
        languageButton: [
            'shr-border-transparent shr-font-normal [&]:shr-justify-start [&]:shr-px-0.5',
            '[&:not(:has(svg))]:shr-ps-[32px]',
            'hover:shr-border-transparent',
        ],
    },
    variants: {
        invert: {
            true: {
                switchButton: '[&&&]:shr-text-black',
            },
        },
    },
});
export const LanguageSwitcher = ({ narrow, invert, decorators, localeMap, locale, defaultLocale, onLanguageSelect, ...props }) => {
    const locales = useMemo(() => Object.entries(localeMap), [localeMap]);
    const triggerLabel = useMemo(() => decorators?.triggerLabel?.(TRIGGER_LABEL) || TRIGGER_LABEL, [decorators]);
    const checkIconAlt = useMemo(() => decorators?.checkIconAlt?.(CHECK_ICON_ALT) || CHECK_ICON_ALT, [decorators]);
    const currentLang = useMemo(() => locale || defaultLocale || Object.keys(localeMap)[0], [locale, defaultLocale, localeMap]);
    const { languageButton, languageItemsList, languageItem, switchButton } = appLauncher();
    const handleLanguageSelect = (code) => {
        if (onLanguageSelect !== undefined) {
            onLanguageSelect(code);
        }
    };
    const handleKeyDown = (e) => {
        const { key, target, currentTarget } = e;
        if (!['ArrowDown', 'ArrowUp', 'ArrowLeft', 'ArrowRight'].includes(key)) {
            return;
        }
        const isUp = key === 'ArrowUp' || key === 'ArrowLeft';
        const isDown = key === 'ArrowDown' || key === 'ArrowRight';
        e.preventDefault();
        const buttons = tabbable(currentTarget);
        const i = buttons.indexOf(target);
        if (isDown) {
            if (i + 1 === buttons.length) {
                buttons.at(0)?.focus();
                return;
            }
            buttons.at(i + 1)?.focus();
            return;
        }
        if (isUp) {
            buttons.at(i - 1)?.focus();
        }
    };
    const NarrowTrigger = (React.createElement(Button, { square: true, suffix: React.createElement(FaCaretDownIcon, null), className: switchButton({ invert }) },
        React.createElement(FaGlobeIcon, { alt: triggerLabel })));
    const Trigger = (React.createElement(Button, { prefix: React.createElement(FaGlobeIcon, null), suffix: React.createElement(FaCaretDownIcon, null), className: switchButton({ invert }) }, triggerLabel));
    return (React.createElement(Dropdown, { ...props },
        React.createElement(DropdownTrigger, null, narrow ? NarrowTrigger : Trigger),
        React.createElement(DropdownContent, { onKeyDown: handleKeyDown, role: "presentation" },
            React.createElement(DropdownScrollArea, { as: "ul", className: languageItemsList() }, locales.map(([code, label]) => {
                const isCurrent = currentLang === code;
                return (React.createElement("li", { key: code, className: languageItem(), "aria-current": isCurrent },
                    React.createElement(Button, { wide: true, prefix: isCurrent ? React.createElement(FaCheckIcon, { color: "MAIN", alt: checkIconAlt }) : null, onClick: () => handleLanguageSelect(code), className: languageButton() }, label)));
            })))));
};
//# sourceMappingURL=LanguageSwitcher.js.map