import React, { useContext, useMemo } from 'react';
import { tv } from 'tailwind-variants';
import { LevelContext } from '../SectioningContent';
import { Text } from '../Text';
import { VisuallyHiddenText } from '../VisuallyHiddenText';
export const MAPPER_SIZE_AND_WEIGHT = {
    screenTitle: {
        size: 'XL',
        leading: 'TIGHT',
        weight: 'normal',
    },
    sectionTitle: {
        size: 'L',
        leading: 'TIGHT',
        weight: 'normal',
    },
    blockTitle: {
        size: 'M',
        leading: 'TIGHT',
        weight: 'bold',
    },
    subBlockTitle: {
        size: 'M',
        leading: 'TIGHT',
        weight: 'bold',
        color: 'TEXT_GREY',
    },
    subSubBlockTitle: {
        size: 'S',
        leading: 'TIGHT',
        weight: 'bold',
        color: 'TEXT_GREY',
    },
};
const generateTagProps = (level, tag) => {
    let role = undefined;
    let ariaLevel = undefined;
    // TODO: h1はPageHeadingで設定するため、自動計算では必ずh2以下になるようにする
    if (!tag && level > 6) {
        role = 'heading';
        ariaLevel = level;
    }
    return {
        as: tag || (level <= 6 ? `h${level}` : 'span'),
        role,
        'aria-level': ariaLevel,
    };
};
const heading = tv({
    base: 'smarthr-ui-Heading',
    variants: {
        visuallyHidden: {
            false: 'shr-m-[unset]',
        },
    },
    defaultVariants: {
        visuallyHidden: false,
    },
});
export const Heading = ({ tag, type = 'sectionTitle', className, visuallyHidden, ...props }) => {
    const level = useContext(LevelContext);
    const tagProps = useMemo(() => generateTagProps(level, tag), [level, tag]);
    const styles = useMemo(() => heading({ visuallyHidden, className }), [className, visuallyHidden]);
    const actualProps = {
        ...props,
        ...MAPPER_SIZE_AND_WEIGHT[type],
        ...tagProps,
        className: styles,
    };
    return visuallyHidden ? React.createElement(VisuallyHiddenText, { ...actualProps }) : React.createElement(Text, { ...actualProps });
};
export const PageHeading = ({ type = 'screenTitle', ...props }) => React.createElement(Heading, { ...props, type: type, tag: "h1" }); // eslint-disable-line smarthr/a11y-heading-in-sectioning-content
//# sourceMappingURL=Heading.js.map