"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LanguageSwitcher = void 0;
const react_1 = __importStar(require("react"));
const tailwind_variants_1 = require("tailwind-variants");
const tabbable_1 = require("../../../libs/tabbable");
const Button_1 = require("../../Button");
const Dropdown_1 = require("../../Dropdown");
const Icon_1 = require("../../Icon");
const TRIGGER_LABEL = 'Language';
const CHECK_ICON_ALT = '選択中';
const appLauncher = (0, tailwind_variants_1.tv)({
    slots: {
        switchButton: [
            'shr-border-transparent shr-font-normal shr-text-white shr-transition-transform shr-duration-100 [&]:shr-bg-transparent [&]:shr-px-0.25',
            'hover:shr-border-transparent hover:[&]:shr-bg-transparent',
            'focus-visible:shr-border-transparent focus-visible:[&]:shr-bg-transparent',
            '[&>svg]:aria-[expanded=true]:shr-rotate-180',
        ],
        languageItemsList: ['shr-p-0.5'],
        languageItem: ['shr-flex shr-items-center'],
        languageButton: [
            'shr-border-transparent shr-font-normal [&]:shr-justify-start [&]:shr-px-0.5',
            '[&:not(:has(svg))]:shr-ps-[32px]',
            'hover:shr-border-transparent',
        ],
    },
    variants: {
        invert: {
            true: {
                switchButton: '[&&&]:shr-text-black',
            },
        },
    },
});
const LanguageSwitcher = ({ narrow, invert, decorators, localeMap, locale, defaultLocale, onLanguageSelect, ...props }) => {
    const locales = (0, react_1.useMemo)(() => Object.entries(localeMap), [localeMap]);
    const triggerLabel = (0, react_1.useMemo)(() => decorators?.triggerLabel?.(TRIGGER_LABEL) || TRIGGER_LABEL, [decorators]);
    const checkIconAlt = (0, react_1.useMemo)(() => decorators?.checkIconAlt?.(CHECK_ICON_ALT) || CHECK_ICON_ALT, [decorators]);
    const currentLang = (0, react_1.useMemo)(() => locale || defaultLocale || Object.keys(localeMap)[0], [locale, defaultLocale, localeMap]);
    const { languageButton, languageItemsList, languageItem, switchButton } = appLauncher();
    const handleLanguageSelect = (code) => {
        if (onLanguageSelect !== undefined) {
            onLanguageSelect(code);
        }
    };
    const handleKeyDown = (e) => {
        const { key, target, currentTarget } = e;
        if (!['ArrowDown', 'ArrowUp', 'ArrowLeft', 'ArrowRight'].includes(key)) {
            return;
        }
        const isUp = key === 'ArrowUp' || key === 'ArrowLeft';
        const isDown = key === 'ArrowDown' || key === 'ArrowRight';
        e.preventDefault();
        const buttons = (0, tabbable_1.tabbable)(currentTarget);
        const i = buttons.indexOf(target);
        if (isDown) {
            if (i + 1 === buttons.length) {
                buttons.at(0)?.focus();
                return;
            }
            buttons.at(i + 1)?.focus();
            return;
        }
        if (isUp) {
            buttons.at(i - 1)?.focus();
        }
    };
    const NarrowTrigger = (react_1.default.createElement(Button_1.Button, { square: true, suffix: react_1.default.createElement(Icon_1.FaCaretDownIcon, null), className: switchButton({ invert }) },
        react_1.default.createElement(Icon_1.FaGlobeIcon, { alt: triggerLabel })));
    const Trigger = (react_1.default.createElement(Button_1.Button, { prefix: react_1.default.createElement(Icon_1.FaGlobeIcon, null), suffix: react_1.default.createElement(Icon_1.FaCaretDownIcon, null), className: switchButton({ invert }) }, triggerLabel));
    return (react_1.default.createElement(Dropdown_1.Dropdown, { ...props },
        react_1.default.createElement(Dropdown_1.DropdownTrigger, null, narrow ? NarrowTrigger : Trigger),
        react_1.default.createElement(Dropdown_1.DropdownContent, { onKeyDown: handleKeyDown, role: "presentation" },
            react_1.default.createElement(Dropdown_1.DropdownScrollArea, { as: "ul", className: languageItemsList() }, locales.map(([code, label]) => {
                const isCurrent = currentLang === code;
                return (react_1.default.createElement("li", { key: code, className: languageItem(), "aria-current": isCurrent },
                    react_1.default.createElement(Button_1.Button, { wide: true, prefix: isCurrent ? react_1.default.createElement(Icon_1.FaCheckIcon, { color: "MAIN", alt: checkIconAlt }) : null, onClick: () => handleLanguageSelect(code), className: languageButton() }, label)));
            })))));
};
exports.LanguageSwitcher = LanguageSwitcher;
//# sourceMappingURL=LanguageSwitcher.js.map